summaryrefslogtreecommitdiff
path: root/cui/source/dialogs/scriptdlg.cxx
diff options
context:
space:
mode:
authorMichael T. Whiteley <mike@whiteley.org>2011-12-07 02:33:51 -0800
committerTor Lillqvist <tlillqvist@suse.com>2011-12-08 11:32:41 +0200
commitdcfd4beb213c551f6ef6ba379651bf303bd9017a (patch)
treea819f50716357c2a5561f6b9a09809cfc52d7dbf /cui/source/dialogs/scriptdlg.cxx
parentad2eb6c4ba3ca36e2302c721a106dac80d266325 (diff)
childs -> children
Diffstat (limited to 'cui/source/dialogs/scriptdlg.cxx')
-rw-r--r--cui/source/dialogs/scriptdlg.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/cui/source/dialogs/scriptdlg.cxx b/cui/source/dialogs/scriptdlg.cxx
index d7f3dd284a37..7e021d020dbd 100644
--- a/cui/source/dialogs/scriptdlg.cxx
+++ b/cui/source/dialogs/scriptdlg.cxx
@@ -423,7 +423,7 @@ SvLBoxEntry * SFTreeListBox::insertEntry(
}
SAL_WNODEPRECATED_DECLARATIONS_POP
-void SFTreeListBox::RequestingChilds( SvLBoxEntry* pEntry )
+void SFTreeListBox::RequestingChildren( SvLBoxEntry* pEntry )
{
SFEntry* userData = 0;
if ( !pEntry )
@@ -992,7 +992,7 @@ void SvxScriptOrgDialog::createEntry( SvLBoxEntry* pEntry )
while ( !bValid );
// open up parent node (which ensures it's loaded)
- aScriptsBox.RequestingChilds( pEntry );
+ aScriptsBox.RequestingChildren( pEntry );
Sequence< Any > args( 1 );
args[ 0 ] <<= aNewName;
@@ -1044,8 +1044,8 @@ void SvxScriptOrgDialog::createEntry( SvLBoxEntry* pEntry )
SAL_WNODEPRECATED_DECLARATIONS_POP
// If the Parent is not loaded then set to
// loaded, this will prevent RequestingChilds ( called
// from vcl via RequestingChilds ) from
// creating new ( duplicate ) children
SFEntry* userData = (SFEntry*)pEntry->GetUserData();
if ( userData && !userData->isLoaded() )
@@ -1284,7 +1284,7 @@ void SvxScriptOrgDialog::RestorePreviousSelection()
}
if ( !pTmpEntry )
break;
- aScriptsBox.RequestingChilds( pEntry );
+ aScriptsBox.RequestingChildren( pEntry );
}
aScriptsBox.SetCurEntry( pEntry );
}
@@ -1044,8 +1044,8 @@ void SvxScriptOrgDialog::createEntry( SvLBoxEntry* pEntry )
SAL_WNODEPRECATED_DECLARATIONS_POP
// If the Parent is not loaded then set to
- // loaded, this will prevent RequestingChilds ( called
- // from vcl via RequestingChilds ) from
+ // loaded, this will prevent RequestingChildren ( called
+ // from vcl via RequestingChildren ) from
// creating new ( duplicate ) children
SFEntry* userData = (SFEntry*)pEntry->GetUserData();